@@ -151,7 +151,7 @@ class BaseHandler(RequestHandler):
                 data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
             self.end_time = int(round(time.time() * 1000))
             self.set_header("Api-Time", f"{self.end_time - self.start_time}ms")
-            if not self.original:
+            if data is not None:
                 self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
         else:
             raise BusinessException(StatusCode.RESOURCE_NOT_FOUND)
@@ -241,6 +241,7 @@ class BaseHandler(RequestHandler):
             data["modify_user_name"] = user.username
         data["modify_time"] = datetime.now()
 
+
 class JSONEncoder(json.JSONEncoder):
     def default(self, o):
         if isinstance(o, ObjectId):
